pub trait Shape {
// Required method
fn describe(d: &mut Desc);
}Expand description
A type that can describe itself.
The description is the type’s identity in the file, so two types that
describe themselves the same way are the same type as far as yo is
concerned, whatever they are called in the host language.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".