parse

Function parse 

pub fn parse(desc: &Desc) -> Result<Type>
Parse a whole description. Trailing bytes are an error, because a description that is a valid type followed by rubbish is not a description.

Errors

Code::Corrupt with the byte offset, for anything that is not a description this build can read.